[][src]Struct system_configuration::network_reachability::ReachabilityFlags

pub struct ReachabilityFlags { /* fields omitted */ }

Rustier interface for SCNetworkReachabilityFlags.

Implementations

impl ReachabilityFlags[src]

pub const TRANSIENT_CONNECTION: ReachabilityFlags[src]

The specified node name or address can be reached via a transient connection, such as PPP.

pub const REACHABLE: ReachabilityFlags[src]

The specified node name or address can be reached using the current network configuration.

pub const CONNECTION_REQUIRED: ReachabilityFlags[src]

The specified node name or address can be reached using the current network configuration, but a connection must first be established. If this flag is set, the CONNECTION_ON_TRAFFIC flag, CONNECTION_ON_DEMAND flag, or IS_WANN flag is also typically set to indicate the type of connection required. If the user must manually make the connection, the INTERVENTION_REQUIRED flag is also set.

pub const CONNECTION_ON_TRAFFIC: ReachabilityFlags[src]

The specified node name or address can be reached using the current network configuration, but a connection must first be established. Any traffic directed to the specified name or address will initiate the connection.

pub const INTERVENTION_REQUIRED: ReachabilityFlags[src]

The specified node name or address can be reached using the current network configuration, but a connection must first be established.

pub const CONNECTION_ON_DEMAND: ReachabilityFlags[src]

The specified node name or address can be reached using the current network configuration, but a connection must first be established.

pub const IS_LOCAL_ADDRESS: ReachabilityFlags[src]

The specified node name or address is one that is associated with a network interface on the current system.

pub const IS_DIRECT: ReachabilityFlags[src]

Network traffic to the specified node name or address will not go through a gateway, but is routed directly to one of the interfaces in the system.

pub const IS_WWAN: ReachabilityFlags[src]

The specified node name or address can be reached via a cellular connection, such as EDGE or GPRS.

pub const fn empty() -> ReachabilityFlags[src]

Returns an empty set of flags

pub const fn all() -> ReachabilityFlags[src]

Returns the set containing all flags.

pub const fn bits(&self) -> u32[src]

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<ReachabilityFlags>[src]

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> ReachabilityFlags[src]

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> ReachabilityFlags[src]

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool[src]

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool[src]

Returns true if all flags are currently set.

pub const fn intersects(&self, other: ReachabilityFlags) -> bool[src]

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: ReachabilityFlags) -> bool[src]

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: ReachabilityFlags)[src]

Inserts the specified flags in-place.

pub fn remove(&mut self, other: ReachabilityFlags)[src]

Removes the specified flags in-place.

pub fn toggle(&mut self, other: ReachabilityFlags)[src]

Toggles the specified flags in-place.

pub fn set(&mut self, other: ReachabilityFlags, value: bool)[src]

Inserts or removes the specified flags depending on the passed value.