[−][src]Struct system_configuration::network_reachability::SCNetworkReachability
A network address or host for which the connectivity can be determined.
See SCNetworkReachability for details.
Implementations
impl SCNetworkReachability[src]
pub fn from_addr_pair(
local: SocketAddr,
remote: SocketAddr
) -> SCNetworkReachability[src]
local: SocketAddr,
remote: SocketAddr
) -> SCNetworkReachability
Construct a SCNetworkReachability struct with a local and a remote socket address.
See SCNetworkReachabilityCreateWithAddressPair for details.
pub fn from_host(host: &CStr) -> Option<Self>[src]
Construct a Reachability from either a hostname or a network node
See SCNetworkReachabilityCreateWithName for details.
pub fn reachability(&self) -> Result<ReachabilityFlags, ReachabilityError>[src]
Return a flag indicating whether the specified network address is reachable.
See SCNetworkReachabilityGetFlags for details.
pub fn schedule_with_runloop(
&self,
run_loop: &CFRunLoop,
run_loop_mode: CFStringRef
) -> Result<(), SchedulingError>[src]
&self,
run_loop: &CFRunLoop,
run_loop_mode: CFStringRef
) -> Result<(), SchedulingError>
Schedule callback with runloop.
See SCNetworkReachabilityScheduleFromRunLoop for details.
pub fn unschedule_from_runloop(
&self,
run_loop: &CFRunLoop,
run_loop_mode: CFStringRef
) -> Result<(), UnschedulingError>[src]
&self,
run_loop: &CFRunLoop,
run_loop_mode: CFStringRef
) -> Result<(), UnschedulingError>
Unschedule from run loop.
See SCNetworkReachabilityUnscheduleFromRunLoop for details.
pub fn set_callback<F: Fn(ReachabilityFlags) + Sync + Send>(
&mut self,
callback: F
) -> Result<(), SetCallbackError>[src]
&mut self,
callback: F
) -> Result<(), SetCallbackError>
Sets callback that is run whenever network connectivity changes. For the callback to be
invoked, the SCNetworkReachability has to be registered on a run loop. Calling this
function multiple times will clear the subsequently set callback.
See SCNetworkReachabilityContext for details.